==> kmymoney-5.1.1.tar.xz: kmymoney-5.1.1/kmymoney/plugins/checkprinting/checkprinting.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[de]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[et]": "Cristian Oneț",
                "Name[eu]": "Cristian Oneț",
                "Name[fi]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[ia]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[ko]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx"
            }
        ],
        "Description": "Provides the capability to print checks",
        "Description[ca@valencia]": "Proporciona la capacitat d'imprimir xecs",
        "Description[ca]": "Proporciona la capacitat d'imprimir xecs",
        "Description[de]": "Stellt die Möglichkeit bereit, Schecks zu drucken",
        "Description[en_GB]": "Provides the capability to print cheques",
        "Description[es]": "Proporciona la capacidad de imprimir cheques",
        "Description[et]": "Tšekkide trükkimise võimalus",
        "Description[eu]": "Txekeak inprimatzeko gaitasuna hornitzen du",
        "Description[fi]": "Tarjoaa kyvyn tulostaa shekkejä",
        "Description[fr]": "Fournit la possibilité d'imprimer des chèques",
        "Description[gl]": "Permite imprimir cheques",
        "Description[it]": "Fornisce la funzionalità di stampa degli assegni",
        "Description[ko]": "수표 발행 기능 제공",
        "Description[nl]": "Levert de mogelijkheid checks af te drukken",
        "Description[pl]": "Dostarcza możliwość drukowania czeków",
        "Description[pt]": "Oferece a possibilidade de imprimir cheques",
        "Description[pt_BR]": "Fornece a capacidade de imprimir cheques",
        "Description[sk]": "Poskytuje možnosť tlačiť účty",
        "Description[sv]": "Tillhandahåller möjlighet att skriva ut checkar",
        "Description[uk]": "Можливість друку чеків",
        "Description[x-test]": "xxProvides the capability to print checksxx",
        "EnabledByDefault": true,
        "Icon": "document-print",
        "Id": "checkprinting",
        "License": "GPL",
        "Name": "Check printing",
        "Name[ca@valencia]": "Impressió de xecs",
        "Name[ca]": "Impressió de xecs",
        "Name[de]": "Scheckdruck",
        "Name[en_GB]": "Cheque printing",
        "Name[es]": "Comprobar la impresión",
        "Name[et]": "Tšeki trükkimine",
        "Name[eu]": "Txeke inprimatzea",
        "Name[fi]": "Sekkien tulostus",
        "Name[fr]": "Impression de chèques",
        "Name[gl]": "Impresión de cheques",
        "Name[ia]": "Imprimente cheque",
        "Name[it]": "Stampa degli assegni",
        "Name[ko]": "수표 발행",
        "Name[nl]": "Printen van een cheque",
        "Name[pl]": "Drukowanie czeków",
        "Name[pt]": "Impressão de cheques",
        "Name[pt_BR]": "Impressão de cheques",
        "Name[sk]": "Skontrolovať tlač",
        "Name[sv]": "Checkutskrift",
        "Name[uk]": "Друк чеків",
        "Name[x-test]": "xxCheck printingxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/checkprinting/checkprinting.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[de]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[et]": "Cristian Oneț",
                "Name[eu]": "Cristian Oneț",
                "Name[fi]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[ia]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[ko]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sl]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx",
                "Name[zh_CN]": "Cristian Oneț"
            }
        ],
        "Description": "Provides the capability to print checks",
        "Description[ca@valencia]": "Proporciona la capacitat d'imprimir xecs",
        "Description[ca]": "Proporciona la capacitat d'imprimir xecs",
        "Description[de]": "Stellt die Möglichkeit bereit, Schecks zu drucken",
        "Description[en_GB]": "Provides the capability to print cheques",
        "Description[es]": "Proporciona la capacidad de imprimir cheques",
        "Description[et]": "Tšekkide trükkimise võimalus",
        "Description[eu]": "Txekeak inprimatzeko gaitasuna hornitzen du",
        "Description[fi]": "Tarjoaa kyvyn tulostaa shekkejä",
        "Description[fr]": "Fournit la possibilité d'imprimer des chèques",
        "Description[gl]": "Permite imprimir cheques",
        "Description[it]": "Fornisce la funzionalità di stampa degli assegni",
        "Description[ko]": "수표 발행 기능 제공",
        "Description[nl]": "Levert de mogelijkheid checks af te drukken",
        "Description[pl]": "Dostarcza możliwość drukowania czeków",
        "Description[pt]": "Oferece a possibilidade de imprimir cheques",
        "Description[pt_BR]": "Fornece a capacidade de imprimir cheques",
        "Description[sk]": "Poskytuje možnosť tlačiť účty",
        "Description[sl]": "Omogoča tiskanje čekov",
        "Description[sv]": "Tillhandahåller möjlighet att skriva ut checkar",
        "Description[uk]": "Можливість друку чеків",
        "Description[x-test]": "xxProvides the capability to print checksxx",
        "Description[zh_CN]": "提供支票打印功能",
        "EnabledByDefault": true,
        "Icon": "document-print",
        "Id": "checkprinting",
        "License": "GPL",
        "Name": "Check printing",
        "Name[ca@valencia]": "Impressió de xecs",
        "Name[ca]": "Impressió de xecs",
        "Name[de]": "Scheckdruck",
        "Name[en_GB]": "Cheque printing",
        "Name[es]": "Comprobar la impresión",
        "Name[et]": "Tšeki trükkimine",
        "Name[eu]": "Txeke inprimatzea",
        "Name[fi]": "Sekkien tulostus",
        "Name[fr]": "Impression de chèques",
        "Name[gl]": "Impresión de cheques",
        "Name[ia]": "Imprimente cheque",
        "Name[it]": "Stampa degli assegni",
        "Name[ko]": "수표 발행",
        "Name[nl]": "Printen van een cheque",
        "Name[pl]": "Drukowanie czeków",
        "Name[pt]": "Impressão de cheques",
        "Name[pt_BR]": "Impressão de cheques",
        "Name[sk]": "Skontrolovať tlač",
        "Name[sl]": "Tiskanje čekov",
        "Name[sv]": "Checkutskrift",
        "Name[uk]": "Друк чеків",
        "Name[x-test]": "xxCheck printingxx",
        "Name[zh_CN]": "支票打印",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
